:github_url: https://github.com/stephane-caron/pink/tree/main/doc/limits.rst

.. _Limits:

******
Limits
******

Definition
==========

.. automodule:: pink.limits.limit
    :members:

Configuration limit
===================

.. automodule:: pink.limits.configuration_limit
   :members:

Velocity limit
==============

.. automodule:: pink.limits.velocity_limit
   :members:

Acceleration limit
==================

.. automodule:: pink.limits.acceleration_limit
   :members:
